# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import subscription_pb2 as eolymp_dot_commerce_dot_subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/commerce/events.proto\x12\x0f\x65olymp.commerce\x1a\"eolymp/commerce/subscription.proto\"w\n\x18SubscriptionChangedEvent\x12-\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x1d.eolymp.commerce.Subscription\x12,\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x1d.eolymp.commerce.SubscriptionB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _SUBSCRIPTIONCHANGEDEVENT._serialized_start=85
  _SUBSCRIPTIONCHANGEDEVENT._serialized_end=204
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = ["birthday", "city", "country", "email", "email_verified", "issuer", "name", "nickname", "nickname_change_timeout", "password", "password_age", "picture", "preferences", "subject", "team_id"]
    class Preferences(_message.Message):
        __slots__ = ["locale", "runtime", "timezone"]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_FIELD_NUMBER: _ClassVar[int]
        TIMEZONE_FIELD_NUMBER: _ClassVar[int]
        locale: str
        runtime: str
        timezone: str
        def __init__(self, locale: _Optional[str] = ..., timezone: _Optional[str] = ..., runtime: _Optional[str] = ...) -> None: ...
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EMAIL_VERIFIED_FIELD_NUMBER: _ClassVar[int]
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NICKNAME_CHANGE_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    NICKNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_AGE_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    PICTURE_FIELD_NUMBER: _ClassVar[int]
    PREFERENCES_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    TEAM_ID_FIELD_NUMBER: _ClassVar[int]
    birthday: _timestamp_pb2.Timestamp
    city: str
    country: str
    email: str
    email_verified: bool
    issuer: str
    name: str
    nickname: str
    nickname_change_timeout: int
    password: str
    password_age: int
    picture: str
    preferences: User.Preferences
    subject: str
    team_id: str
    def __init__(self, issuer: _Optional[str] = ..., subject: _Optional[str] = ..., nickname: _Optional[str] = ..., nickname_change_timeout: _Optional[int] = ..., email: _Optional[str] = ..., email_verified: bool = ..., password: _Optional[str] = ..., password_age: _Optional[int] = ..., name: _Optional[str] = ..., picture: _Optional[str] = ..., birthday: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., country: _Optional[str] = ..., city: _Optional[str] = ..., team_id: _Optional[str] = ..., preferences: _Optional[_Union[User.Preferences, _Mapping]] = ...) -> None: ...



from eolymp.executor import report_pb2 as _report_pb2
from eolymp.executor import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class JobReportedEvent(_message.Message):
    __slots__ = ["report"]
    REPORT_FIELD_NUMBER: _ClassVar[int]
    report: _report_pb2.Report
    def __init__(self, report: _Optional[_Union[_report_pb2.Report, _Mapping]] = ...) -> None: ...

class StatusUpdatedEvent(_message.Message):
    __slots__ = ["status"]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _status_pb2.Status
    def __init__(self, status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ...) -> None: ...



from eolymp.executor import task_pb2 as _task_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Job(_message.Message):
    __slots__ = ["actors", "origin", "preconditions", "reference", "runs", "scenario"]
    class Actor(_message.Message):
        __slots__ = ["env", "files", "footer_ern", "footer_url", "header_ern", "header_url", "mount", "name", "output_format", "runtime", "source_ern", "source_url"]
        class OutputFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        class EnvEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        ENV_FIELD_NUMBER: _ClassVar[int]
        EXIT_CODE: Job.Actor.OutputFormat
        FILES_FIELD_NUMBER: _ClassVar[int]
        FOOTER_ERN_FIELD_NUMBER: _ClassVar[int]
        FOOTER_URL_FIELD_NUMBER: _ClassVar[int]
        HEADER_ERN_FIELD_NUMBER: _ClassVar[int]
        HEADER_URL_FIELD_NUMBER: _ClassVar[int]
        MOUNT_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_FORMAT_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_FIELD_NUMBER: _ClassVar[int]
        SOURCE_ERN_FIELD_NUMBER: _ClassVar[int]
        SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
        TESTLIB_OUTPUT: Job.Actor.OutputFormat
        env: _containers.ScalarMap[str, str]
        files: _containers.RepeatedCompositeFieldContainer[Job.File]
        footer_ern: str
        footer_url: str
        header_ern: str
        header_url: str
        mount: _containers.RepeatedCompositeFieldContainer[Job.Mount]
        name: str
        output_format: Job.Actor.OutputFormat
        runtime: str
        source_ern: str
        source_url: str
        def __init__(self, name: _Optional[str] = ..., runtime: _Optional[str] = ..., source_ern: _Optional[str] = ..., header_ern: _Optional[str] = ..., footer_ern: _Optional[str] = ..., source_url: _Optional[str] = ..., header_url: _Optional[str] = ..., footer_url: _Optional[str] = ..., env: _Optional[_Mapping[str, str]] = ..., files: _Optional[_Iterable[_Union[Job.File, _Mapping]]] = ..., output_format: _Optional[_Union[Job.Actor.OutputFormat, str]] = ..., mount: _Optional[_Iterable[_Union[Job.Mount, _Mapping]]] = ...) -> None: ...
    class File(_message.Message):
        __slots__ = ["path", "source_ern", "source_url"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        SOURCE_ERN_FIELD_NUMBER: _ClassVar[int]
        SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
        path: str
        source_ern: str
        source_url: str
        def __init__(self, path: _Optional[str] = ..., source_ern: _Optional[str] = ..., source_url: _Optional[str] = ...) -> None: ...
    class Mount(_message.Message):
        __slots__ = ["from_actor", "to_path"]
        FROM_ACTOR_FIELD_NUMBER: _ClassVar[int]
        TO_PATH_FIELD_NUMBER: _ClassVar[int]
        from_actor: str
        to_path: str
        def __init__(self, from_actor: _Optional[str] = ..., to_path: _Optional[str] = ...) -> None: ...
    class Run(_message.Message):
        __slots__ = ["index", "labels", "reference", "steps"]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        LABELS_FIELD_NUMBER: _ClassVar[int]
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        STEPS_FIELD_NUMBER: _ClassVar[int]
        index: int
        labels: _containers.RepeatedScalarFieldContainer[str]
        reference: str
        steps: _containers.RepeatedCompositeFieldContainer[Job.Step]
        def __init__(self, reference: _Optional[str] = ..., index: _Optional[int] = ..., labels: _Optional[_Iterable[str]] = ..., steps: _Optional[_Iterable[_Union[Job.Step, _Mapping]]] = ...) -> None: ...
    class Step(_message.Message):
        __slots__ = ["copy", "even_on_failure", "execute", "group", "name", "only_on_failure", "upload", "write"]
        class Copy(_message.Message):
            __slots__ = ["optionally", "remove_source", "source_actor", "source_path", "target_actor", "target_path"]
            OPTIONALLY_FIELD_NUMBER: _ClassVar[int]
            REMOVE_SOURCE_FIELD_NUMBER: _ClassVar[int]
            SOURCE_ACTOR_FIELD_NUMBER: _ClassVar[int]
            SOURCE_PATH_FIELD_NUMBER: _ClassVar[int]
            TARGET_ACTOR_FIELD_NUMBER: _ClassVar[int]
            TARGET_PATH_FIELD_NUMBER: _ClassVar[int]
            optionally: bool
            remove_source: bool
            source_actor: str
            source_path: str
            target_actor: str
            target_path: str
            def __init__(self, source_actor: _Optional[str] = ..., source_path: _Optional[str] = ..., target_actor: _Optional[str] = ..., target_path: _Optional[str] = ..., optionally: bool = ..., remove_source: bool = ...) -> None: ...
        class Execute(_message.Message):
            __slots__ = ["actor", "args", "cpu_time_limit", "env", "file_size_limit", "memory_limit", "stderr", "stdin", "stdin_last", "stdout", "wall_time_limit"]
            class EnvEntry(_message.Message):
                __slots__ = ["key", "value"]
                KEY_FIELD_NUMBER: _ClassVar[int]
                VALUE_FIELD_NUMBER: _ClassVar[int]
                key: str
                value: str
                def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
            ACTOR_FIELD_NUMBER: _ClassVar[int]
            ARGS_FIELD_NUMBER: _ClassVar[int]
            CPU_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
            ENV_FIELD_NUMBER: _ClassVar[int]
            FILE_SIZE_LIMIT_FIELD_NUMBER: _ClassVar[int]
            MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
            STDERR_FIELD_NUMBER: _ClassVar[int]
            STDIN_FIELD_NUMBER: _ClassVar[int]
            STDIN_LAST_FIELD_NUMBER: _ClassVar[int]
            STDOUT_FIELD_NUMBER: _ClassVar[int]
            WALL_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
            actor: str
            args: _containers.RepeatedScalarFieldContainer[str]
            cpu_time_limit: int
            env: _containers.ScalarMap[str, str]
            file_size_limit: int
            memory_limit: int
            stderr: str
            stdin: str
            stdin_last: bool
            stdout: str
            wall_time_limit: int
            def __init__(self, actor: _Optional[str] = ..., args: _Optional[_Iterable[str]] = ..., env: _Optional[_Mapping[str, str]] = ..., stdin: _Optional[str] = ..., stdout: _Optional[str] = ..., stderr: _Optional[str] = ..., stdin_last: bool = ..., wall_time_limit: _Optional[int] = ..., cpu_time_limit: _Optional[int] = ..., memory_limit: _Optional[int] = ..., file_size_limit: _Optional[int] = ...) -> None: ...
        class Group(_message.Message):
            __slots__ = ["processes"]
            PROCESSES_FIELD_NUMBER: _ClassVar[int]
            processes: _containers.RepeatedCompositeFieldContainer[Job.Step.Execute]
            def __init__(self, processes: _Optional[_Iterable[_Union[Job.Step.Execute, _Mapping]]] = ...) -> None: ...
        class Upload(_message.Message):
            __slots__ = ["force_upload", "max_data_size", "max_size", "optionally", "source_actor", "source_path", "target_name", "ttl"]
            FORCE_UPLOAD_FIELD_NUMBER: _ClassVar[int]
            MAX_DATA_SIZE_FIELD_NUMBER: _ClassVar[int]
            MAX_SIZE_FIELD_NUMBER: _ClassVar[int]
            OPTIONALLY_FIELD_NUMBER: _ClassVar[int]
            SOURCE_ACTOR_FIELD_NUMBER: _ClassVar[int]
            SOURCE_PATH_FIELD_NUMBER: _ClassVar[int]
            TARGET_NAME_FIELD_NUMBER: _ClassVar[int]
            TTL_FIELD_NUMBER: _ClassVar[int]
            force_upload: bool
            max_data_size: int
            max_size: int
            optionally: bool
            source_actor: str
            source_path: str
            target_name: str
            ttl: int
            def __init__(self, source_actor: _Optional[str] = ..., source_path: _Optional[str] = ..., target_name: _Optional[str] = ..., optionally: bool = ..., ttl: _Optional[int] = ..., max_size: _Optional[int] = ..., max_data_size: _Optional[int] = ..., force_upload: bool = ...) -> None: ...
        class Write(_message.Message):
            __slots__ = ["fix_crlf", "source_ern", "source_url", "target_actor", "target_path"]
            FIX_CRLF_FIELD_NUMBER: _ClassVar[int]
            SOURCE_ERN_FIELD_NUMBER: _ClassVar[int]
            SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
            TARGET_ACTOR_FIELD_NUMBER: _ClassVar[int]
            TARGET_PATH_FIELD_NUMBER: _ClassVar[int]
            fix_crlf: bool
            source_ern: str
            source_url: str
            target_actor: str
            target_path: str
            def __init__(self, source_ern: _Optional[str] = ..., source_url: _Optional[str] = ..., target_actor: _Optional[str] = ..., target_path: _Optional[str] = ..., fix_crlf: bool = ...) -> None: ...
        COPY_FIELD_NUMBER: _ClassVar[int]
        EVEN_ON_FAILURE_FIELD_NUMBER: _ClassVar[int]
        EXECUTE_FIELD_NUMBER: _ClassVar[int]
        GROUP_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        ONLY_ON_FAILURE_FIELD_NUMBER: _ClassVar[int]
        UPLOAD_FIELD_NUMBER: _ClassVar[int]
        WRITE_FIELD_NUMBER: _ClassVar[int]
        copy: Job.Step.Copy
        even_on_failure: bool
        execute: Job.Step.Execute
        group: Job.Step.Group
        name: str
        only_on_failure: bool
        upload: Job.Step.Upload
        write: Job.Step.Write
        def __init__(self, name: _Optional[str] = ..., even_on_failure: bool = ..., only_on_failure: bool = ..., write: _Optional[_Union[Job.Step.Write, _Mapping]] = ..., copy: _Optional[_Union[Job.Step.Copy, _Mapping]] = ..., execute: _Optional[_Union[Job.Step.Execute, _Mapping]] = ..., upload: _Optional[_Union[Job.Step.Upload, _Mapping]] = ..., group: _Optional[_Union[Job.Step.Group, _Mapping]] = ...) -> None: ...
    ACTORS_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    PRECONDITIONS_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    SCENARIO_FIELD_NUMBER: _ClassVar[int]
    actors: _containers.RepeatedCompositeFieldContainer[Job.Actor]
    origin: str
    preconditions: _containers.RepeatedCompositeFieldContainer[_task_pb2.Task.Precondition]
    reference: str
    runs: _containers.RepeatedCompositeFieldContainer[Job.Run]
    scenario: _containers.RepeatedCompositeFieldContainer[Job.Step]
    def __init__(self, reference: _Optional[str] = ..., origin: _Optional[str] = ..., preconditions: _Optional[_Iterable[_Union[_task_pb2.Task.Precondition, _Mapping]]] = ..., actors: _Optional[_Iterable[_Union[Job.Actor, _Mapping]]] = ..., scenario: _Optional[_Iterable[_Union[Job.Step, _Mapping]]] = ..., runs: _Optional[_Iterable[_Union[Job.Run, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/customer_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.commerce import customer_pb2 as eolymp_dot_commerce_dot_customer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/commerce/customer_service.proto\x12\x0f\x65olymp.commerce\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/commerce/customer.proto\"B\n\x13\x43reateCustomerInput\x12+\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x19.eolymp.commerce.Customer\"+\n\x14\x43reateCustomerOutput\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\"W\n\x13UpdateCustomerInput\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12+\n\x08\x63ustomer\x18\x02 \x01(\x0b\x32\x19.eolymp.commerce.Customer\"\x16\n\x14UpdateCustomerOutput\"\x14\n\x12ListCustomersInput\"N\n\x13ListCustomersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.commerce.Customer\",\n\x15\x44\x65scribeCustomerInput\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeCustomerOutput\x12+\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x19.eolymp.commerce.Customer\"*\n\x13\x44\x65leteCustomerInput\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteCustomerOutput2\xc4\x04\n\x0f\x43ustomerService\x12n\n\x0e\x43reateCustomer\x12$.eolymp.commerce.CreateCustomerInput\x1a%.eolymp.commerce.CreateCustomerOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12n\n\x0eUpdateCustomer\x12$.eolymp.commerce.UpdateCustomerInput\x1a%.eolymp.commerce.UpdateCustomerOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12t\n\x10\x44\x65scribeCustomer\x12&.eolymp.commerce.DescribeCustomerInput\x1a\'.eolymp.commerce.DescribeCustomerOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12k\n\rListCustomers\x12#.eolymp.commerce.ListCustomersInput\x1a$.eolymp.commerce.ListCustomersOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12n\n\x0e\x44\x65leteCustomer\x12$.eolymp.commerce.DeleteCustomerInput\x1a%.eolymp.commerce.DeleteCustomerOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2B3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.customer_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _CUSTOMERSERVICE.methods_by_name['CreateCustomer']._options = None
  _CUSTOMERSERVICE.methods_by_name['CreateCustomer']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CUSTOMERSERVICE.methods_by_name['UpdateCustomer']._options = None
  _CUSTOMERSERVICE.methods_by_name['UpdateCustomer']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CUSTOMERSERVICE.methods_by_name['DescribeCustomer']._options = None
  _CUSTOMERSERVICE.methods_by_name['DescribeCustomer']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CUSTOMERSERVICE.methods_by_name['ListCustomers']._options = None
  _CUSTOMERSERVICE.methods_by_name['ListCustomers']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CUSTOMERSERVICE.methods_by_name['DeleteCustomer']._options = None
  _CUSTOMERSERVICE.methods_by_name['DeleteCustomer']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CREATECUSTOMERINPUT._serialized_start=127
  _CREATECUSTOMERINPUT._serialized_end=193
  _CREATECUSTOMEROUTPUT._serialized_start=195
  _CREATECUSTOMEROUTPUT._serialized_end=238
  _UPDATECUSTOMERINPUT._serialized_start=240
  _UPDATECUSTOMERINPUT._serialized_end=327
  _UPDATECUSTOMEROUTPUT._serialized_start=329
  _UPDATECUSTOMEROUTPUT._serialized_end=351
  _LISTCUSTOMERSINPUT._serialized_start=353
  _LISTCUSTOMERSINPUT._serialized_end=373
  _LISTCUSTOMERSOUTPUT._serialized_start=375
  _LISTCUSTOMERSOUTPUT._serialized_end=453
  _DESCRIBECUSTOMERINPUT._serialized_start=455
  _DESCRIBECUSTOMERINPUT._serialized_end=499
  _DESCRIBECUSTOMEROUTPUT._serialized_start=501
  _DESCRIBECUSTOMEROUTPUT._serialized_end=570
  _DELETECUSTOMERINPUT._serialized_start=572
  _DELETECUSTOMERINPUT._serialized_end=614
  _DELETECUSTOMEROUTPUT._serialized_start=616
  _DELETECUSTOMEROUTPUT._serialized_end=638
  _CUSTOMERSERVICE._serialized_start=641
  _CUSTOMERSERVICE._serialized_end=1221
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.commerce import subscription_pb2 as _subscription_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CancelSubscriptionInput(_message.Message):
    __slots__ = ["subscription_id"]
    SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    subscription_id: str
    def __init__(self, subscription_id: _Optional[str] = ...) -> None: ...

class CancelSubscriptionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateSubscriptionInput(_message.Message):
    __slots__ = ["subscription"]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    subscription: _subscription_pb2.Subscription
    def __init__(self, subscription: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ...) -> None: ...

class CreateSubscriptionOutput(_message.Message):
    __slots__ = ["checkout_url", "subscription_id"]
    CHECKOUT_URL_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    checkout_url: str
    subscription_id: str
    def __init__(self, subscription_id: _Optional[str] = ..., checkout_url: _Optional[str] = ...) -> None: ...

class DescribeSubscriptionInput(_message.Message):
    __slots__ = ["subscription_id"]
    SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    subscription_id: str
    def __init__(self, subscription_id: _Optional[str] = ...) -> None: ...

class DescribeSubscriptionOutput(_message.Message):
    __slots__ = ["subscription"]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    subscription: _subscription_pb2.Subscription
    def __init__(self, subscription: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ...) -> None: ...

class ListSubscriptionsInput(_message.Message):
    __slots__ = ["after", "before", "customer_id", "price_id", "size", "status"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PRICE_ID_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    after: str
    before: str
    customer_id: str
    price_id: str
    size: int
    status: str
    def __init__(self, customer_id: _Optional[str] = ..., price_id: _Optional[str] = ..., status: _Optional[str] = ..., size: _Optional[int] = ..., after: _Optional[str] = ..., before: _Optional[str] = ...) -> None: ...

class ListSubscriptionsOutput(_message.Message):
    __slots__ = ["has_more", "items"]
    HAS_MORE_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    has_more: bool
    items: _containers.RepeatedCompositeFieldContainer[_subscription_pb2.Subscription]
    def __init__(self, has_more: bool = ..., items: _Optional[_Iterable[_Union[_subscription_pb2.Subscription, _Mapping]]] = ...) -> None: ...

class UpdateSubscriptionInput(_message.Message):
    __slots__ = ["subscription", "subscription_id"]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    subscription: _subscription_pb2.Subscription
    subscription_id: str
    def __init__(self, subscription_id: _Optional[str] = ..., subscription: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ...) -> None: ...

class UpdateSubscriptionOutput(_message.Message):
    __slots__ = ["checkout_url"]
    CHECKOUT_URL_FIELD_NUMBER: _ClassVar[int]
    checkout_url: str
    def __init__(self, checkout_url: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ExecutorClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DescribeLanguage(self, request, **kwargs):
        path = "/exec/languages/"+urllib.parse.quote(request.language_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.language_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.executor.DescribeLanguageOutput"),
            **kwargs,
        )

    def ListLanguages(self, request, **kwargs):
        path = "/exec/languages"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.executor.ListLanguagesOutput"),
            **kwargs,
        )

    def DescribeRuntime(self, request, **kwargs):
        path = "/exec/runtime/"+urllib.parse.quote(request.runtime_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.runtime_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.executor.DescribeRuntimeOutput"),
            **kwargs,
        )

    def ListRuntime(self, request, **kwargs):
        path = "/exec/runtime"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.executor.ListRuntimeOutput"),
            **kwargs,
        )

    def DescribeCodeTemplate(self, request, **kwargs):
        path = "/exec/runtime/"+urllib.parse.quote(request.runtime_id)+"/template"

        # Cleanup URL parameters to avoid any ambiguity
        request.runtime_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.executor.DescribeCodeTemplateOutput"),
            **kwargs,
        )




from eolymp.commerce import address_pb2 as _address_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Customer(_message.Message):
    __slots__ = ["address", "currency", "description", "email", "id", "language", "metadata", "name", "phone", "tax_id_type", "tax_id_value"]
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PHONE_FIELD_NUMBER: _ClassVar[int]
    TAX_ID_TYPE_FIELD_NUMBER: _ClassVar[int]
    TAX_ID_VALUE_FIELD_NUMBER: _ClassVar[int]
    address: _address_pb2.Address
    currency: str
    description: str
    email: str
    id: str
    language: str
    metadata: _containers.ScalarMap[str, str]
    name: str
    phone: str
    tax_id_type: str
    tax_id_value: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., email: _Optional[str] = ..., phone: _Optional[str] = ..., tax_id_type: _Optional[str] = ..., tax_id_value: _Optional[str] = ..., address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., currency: _Optional[str] = ..., language: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ProblemServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DeleteProblem(self, request, **kwargs):
        path = "/"

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteProblemOutput"),
            **kwargs,
        )

    def UpdateProblem(self, request, **kwargs):
        path = "/"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateProblemOutput"),
            **kwargs,
        )

    def SyncProblem(self, request, **kwargs):
        path = "/sync"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.SyncProblemOutput"),
            **kwargs,
        )

    def DescribeProblem(self, request, **kwargs):
        path = "/"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeProblemOutput"),
            **kwargs,
        )

    def UpdateVisibility(self, request, **kwargs):
        path = "/visibility"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateVisibilityOutput"),
            **kwargs,
        )

    def UpdatePrivacy(self, request, **kwargs):
        path = "/privacy"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdatePrivacyOutput"),
            **kwargs,
        )

    def ListVersions(self, request, **kwargs):
        path = "/versions"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListVersionsOutput"),
            **kwargs,
        )




from eolymp.commerce import price_pb2 as _price_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Subscription(_message.Message):
    __slots__ = ["cancel_at", "cancellation_comment", "cancellation_feedback", "cancellation_reason", "cancelled_at", "created_at", "currency", "customer_id", "description", "ended_at", "id", "items", "period_end", "period_start", "started_at", "status", "trial_end", "trial_start"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Item(_message.Message):
        __slots__ = ["id", "price", "product_id", "quantity"]
        ID_FIELD_NUMBER: _ClassVar[int]
        PRICE_FIELD_NUMBER: _ClassVar[int]
        PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
        QUANTITY_FIELD_NUMBER: _ClassVar[int]
        id: str
        price: _price_pb2.Price
        product_id: str
        quantity: int
        def __init__(self, id: _Optional[str] = ..., quantity: _Optional[int] = ..., product_id: _Optional[str] = ..., price: _Optional[_Union[_price_pb2.Price, _Mapping]] = ...) -> None: ...
    ACTIVE: Subscription.Status
    CANCELLATION_COMMENT_FIELD_NUMBER: _ClassVar[int]
    CANCELLATION_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    CANCELLATION_REASON_FIELD_NUMBER: _ClassVar[int]
    CANCELLED: Subscription.Status
    CANCELLED_AT_FIELD_NUMBER: _ClassVar[int]
    CANCEL_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ENDED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INCOMPLETE: Subscription.Status
    INCOMPLETE_EXPIRED: Subscription.Status
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    PAST_DUE: Subscription.Status
    PERIOD_END_FIELD_NUMBER: _ClassVar[int]
    PERIOD_START_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TRIALING: Subscription.Status
    TRIAL_END_FIELD_NUMBER: _ClassVar[int]
    TRIAL_START_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_STATUS: Subscription.Status
    UNPAID: Subscription.Status
    cancel_at: _timestamp_pb2.Timestamp
    cancellation_comment: str
    cancellation_feedback: str
    cancellation_reason: str
    cancelled_at: _timestamp_pb2.Timestamp
    created_at: _timestamp_pb2.Timestamp
    currency: str
    customer_id: str
    description: str
    ended_at: _timestamp_pb2.Timestamp
    id: str
    items: _containers.RepeatedCompositeFieldContainer[Subscription.Item]
    period_end: _timestamp_pb2.Timestamp
    period_start: _timestamp_pb2.Timestamp
    started_at: _timestamp_pb2.Timestamp
    status: Subscription.Status
    trial_end: _timestamp_pb2.Timestamp
    trial_start: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[Subscription.Status, str]] = ..., customer_id: _Optional[str] = ..., description: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., cancel_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., cancelled_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ended_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., period_start: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., period_end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., trial_start: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., trial_end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., cancellation_comment: _Optional[str] = ..., cancellation_feedback: _Optional[str] = ..., cancellation_reason: _Optional[str] = ..., currency: _Optional[str] = ..., items: _Optional[_Iterable[_Union[Subscription.Item, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/member.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_ghost_pb2 as eolymp_dot_community_dot_member__ghost__pb2
from eolymp.community import member_team_pb2 as eolymp_dot_community_dot_member__team__pb2
from eolymp.community import member_user_pb2 as eolymp_dot_community_dot_member__user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/community/member.proto\x12\x10\x65olymp.community\x1a eolymp/community/attribute.proto\x1a#eolymp/community/member_ghost.proto\x1a\"eolymp/community/member_team.proto\x1a\"eolymp/community/member_user.proto\"\xe3\x02\n\x06Member\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\n \x01(\x08\x12\x12\n\nincomplete\x18\x14 \x01(\x08\x12\x12\n\nunofficial\x18\x1e \x01(\x08\x12\x0e\n\x06secret\x18( \x01(\x08\x12\x0f\n\x07tier_id\x18\x32 \x01(\t\x12\x18\n\x10\x66\x61llback_tier_id\x18\x33 \x01(\t\x12&\n\x04user\x18\x64 \x01(\x0b\x32\x16.eolymp.community.UserH\x00\x12&\n\x04team\x18\x65 \x01(\x0b\x32\x16.eolymp.community.TeamH\x00\x12(\n\x05ghost\x18\x66 \x01(\x0b\x32\x17.eolymp.community.GhostH\x00\x12\x0f\n\x06groups\x18\xc8\x01 \x03(\t\x12\x36\n\nattributes\x18\x84\x07 \x03(\x0b\x32!.eolymp.community.Attribute.ValueB\t\n\x07\x61\x63\x63ountB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _MEMBER._serialized_start=195
  _MEMBER._serialized_end=550
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/subscription.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import price_pb2 as eolymp_dot_commerce_dot_price__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/commerce/subscription.proto\x12\x0f\x65olymp.commerce\x1a\x1b\x65olymp/commerce/price.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb6\x07\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32$.eolymp.commerce.Subscription.Status\x12\x13\n\x0b\x63ustomer_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tcancel_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cperiod_start\x18( \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nperiod_end\x18) \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0btrial_start\x18\x46 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\ttrial_end\x18G \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14\x63\x61ncellation_comment\x18\x32 \x01(\t\x12\x1d\n\x15\x63\x61ncellation_feedback\x18\x33 \x01(\t\x12\x1b\n\x13\x63\x61ncellation_reason\x18\x34 \x01(\t\x12\x10\n\x08\x63urrency\x18\x1f \x01(\t\x12\x32\n\x05items\x18\xe7\x07 \x03(\x0b\x32\".eolymp.commerce.Subscription.Item\x1a_\n\x04Item\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\x05\x12\x12\n\nproduct_id\x18\x03 \x01(\t\x12%\n\x05price\x18\x04 \x01(\x0b\x32\x16.eolymp.commerce.Price\"\x87\x01\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0e\n\nINCOMPLETE\x10\x01\x12\x16\n\x12INCOMPLETE_EXPIRED\x10\x02\x12\x0c\n\x08TRIALING\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04\x12\x0c\n\x08PAST_DUE\x10\x05\x12\r\n\tCANCELLED\x10\x06\x12\n\n\x06UNPAID\x10\x07\x42\x33Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.subscription_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _SUBSCRIPTION._serialized_start=118
  _SUBSCRIPTION._serialized_end=1068
  _SUBSCRIPTION_ITEM._serialized_start=835
  _SUBSCRIPTION_ITEM._serialized_end=930
  _SUBSCRIPTION_STATUS._serialized_start=933
  _SUBSCRIPTION_STATUS._serialized_end=1068
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Consent(_message.Message):
    __slots__ = ["agreement_id", "id", "revocable", "set_on", "status", "user_id"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ACCEPTED: Consent.Status
    AGREEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PENDING: Consent.Status
    REJECTED: Consent.Status
    REVOCABLE_FIELD_NUMBER: _ClassVar[int]
    SET_ON_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    agreement_id: str
    id: str
    revocable: bool
    set_on: _timestamp_pb2.Timestamp
    status: Consent.Status
    user_id: str
    def __init__(self, id: _Optional[str] = ..., agreement_id: _Optional[str] = ..., user_id: _Optional[str] = ..., revocable: bool = ..., status: _Optional[_Union[Consent.Status, str]] = ..., set_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from eolymp.helpdesk import document_pb2 as _document_pb2
from eolymp.helpdesk import ticket_pb2 as _ticket_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommentChangedEvent(_message.Message):
    __slots__ = ["after", "before", "ticket_id"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    TICKET_ID_FIELD_NUMBER: _ClassVar[int]
    after: _ticket_pb2.Ticket.Comment
    before: _ticket_pb2.Ticket.Comment
    ticket_id: str
    def __init__(self, ticket_id: _Optional[str] = ..., before: _Optional[_Union[_ticket_pb2.Ticket.Comment, _Mapping]] = ..., after: _Optional[_Union[_ticket_pb2.Ticket.Comment, _Mapping]] = ...) -> None: ...

class DocumentCreatedEvent(_message.Message):
    __slots__ = ["document"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    def __init__(self, document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...

class DocumentDeletedEvent(_message.Message):
    __slots__ = ["document"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    def __init__(self, document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...

class DocumentUpdatedEvent(_message.Message):
    __slots__ = ["document"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    def __init__(self, document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...

class TicketChangedEvent(_message.Message):
    __slots__ = ["after", "before"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    after: _ticket_pb2.Ticket
    before: _ticket_pb2.Ticket
    def __init__(self, before: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ..., after: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class StarAddedEvent(_message.Message):
    __slots__ = ["problem_id", "user_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    user_id: str
    def __init__(self, problem_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class StarRemovedEvent(_message.Message):
    __slots__ = ["problem_id", "user_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    user_id: str
    def __init__(self, problem_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/taxonomy/link_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/taxonomy/link_service.proto\x12\x0f\x65olymp.taxonomy\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"&\n\x14SetLinkedTopicsInput\x12\x0e\n\x06topics\x18\x01 \x03(\t\"\x17\n\x15SetLinkedTopicsOutput\"\x16\n\x14GetLinkedTopicsInput\"\'\n\x15GetLinkedTopicsOutput\x12\x0e\n\x06topics\x18\x01 \x03(\t2\xc9\x02\n\x0bLinkService\x12\x9b\x01\n\x0fSetLinkedTopics\x12%.eolymp.taxonomy.SetLinkedTopicsInput\x1a&.eolymp.taxonomy.SetLinkedTopicsOutput\"9\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:topic:link\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\t\x1a\x07/topics\x12\x9b\x01\n\x0fGetLinkedTopics\x12%.eolymp.taxonomy.GetLinkedTopicsInput\x1a&.eolymp.taxonomy.GetLinkedTopicsOutput\"9\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:topic:read\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\t\x12\x07/topicsB3Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.taxonomy.link_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomy'
  _LINKSERVICE.methods_by_name['SetLinkedTopics']._options = None
  _LINKSERVICE.methods_by_name['SetLinkedTopics']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:topic:link\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\t\032\007/topics'
  _LINKSERVICE.methods_by_name['GetLinkedTopics']._options = None
  _LINKSERVICE.methods_by_name['GetLinkedTopics']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:topic:read\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\t\022\007/topics'
  _SETLINKEDTOPICSINPUT._serialized_start=154
  _SETLINKEDTOPICSINPUT._serialized_end=192
  _SETLINKEDTOPICSOUTPUT._serialized_start=194
  _SETLINKEDTOPICSOUTPUT._serialized_end=217
  _GETLINKEDTOPICSINPUT._serialized_start=219
  _GETLINKEDTOPICSINPUT._serialized_end=241
  _GETLINKEDTOPICSOUTPUT._serialized_start=243
  _GETLINKEDTOPICSOUTPUT._serialized_end=282
  _LINKSERVICE._serialized_start=285
  _LINKSERVICE._serialized_end=614
# @@protoc_insertion_point(module_scope)



from eolymp.acl import acl_service_pb2 as _acl_service_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PermissionChangeRecord(_message.Message):
    __slots__ = ["op", "permission", "space_id"]
    class Operation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    GRANT: PermissionChangeRecord.Operation
    NO_OPERATION: PermissionChangeRecord.Operation
    OP_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    REVOKE: PermissionChangeRecord.Operation
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    op: PermissionChangeRecord.Operation
    permission: _acl_service_pb2.Permission
    space_id: str
    def __init__(self, op: _Optional[_Union[PermissionChangeRecord.Operation, str]] = ..., space_id: _Optional[str] = ..., permission: _Optional[_Union[_acl_service_pb2.Permission, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/discussion_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import discussion_pb2 as eolymp_dot_discussion_dot_discussion__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*eolymp/discussion/discussion_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/discussion/discussion.proto\x1a!eolymp/wellknown/expression.proto\"@\n\x17\x44\x65scribeDiscussionInput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\"M\n\x18\x44\x65scribeDiscussionOutput\x12\x31\n\ndiscussion\x18\x01 \x01(\x0b\x32\x1d.eolymp.discussion.Discussion\"\xca\x01\n\x14ListDiscussionsInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12?\n\x07\x66ilters\x18( \x01(\x0b\x32..eolymp.discussion.ListDiscussionsInput.Filter\x1a\x43\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"T\n\x15ListDiscussionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.discussion.Discussion\"J\n\x15\x43reateDiscussionInput\x12\x31\n\ndiscussion\x18\x01 \x01(\x0b\x32\x1d.eolymp.discussion.Discussion\"/\n\x16\x43reateDiscussionOutput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\"a\n\x15UpdateDiscussionInput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\x12\x31\n\ndiscussion\x18\x02 \x01(\x0b\x32\x1d.eolymp.discussion.Discussion\"\x18\n\x16UpdateDiscussionOutput\".\n\x15\x44\x65leteDiscussionInput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteDiscussionOutput\":\n\x13VoteDiscussionInput\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"*\n\x14VoteDiscussionOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\x32\x80\t\n\x11\x44iscussionService\x12\xc5\x01\n\x12\x44\x65scribeDiscussion\x12*.eolymp.discussion.DescribeDiscussionInput\x1a+.eolymp.discussion.DescribeDiscussionOutput\"V\x82\xe3\n\x1e\x8a\xe3\n\x1a\x64iscussion:discussion:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x1e\x12\x1c/discussions/{discussion_id}\x12\xab\x01\n\x0fListDiscussions\x12\'.eolymp.discussion.ListDiscussionsInput\x1a(.eolymp.discussion.ListDiscussionsOutput\"E\x82\xe3\n\x1e\x8a\xe3\n\x1a\x64iscussion:discussion:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/discussions\x12\xaf\x01\n\x10\x43reateDiscussion\x12(.eolymp.discussion.CreateDiscussionInput\x1a).eolymp.discussion.CreateDiscussionOutput\"F\x82\xe3\n\x1f\x8a\xe3\n\x1b\x64iscussion:discussion:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\"\x0c/discussions\x12\xbf\x01\n\x10UpdateDiscussion\x12(.eolymp.discussion.UpdateDiscussionInput\x1a).eolymp.discussion.UpdateDiscussionOutput\"V\x82\xe3\n\x1f\x8a\xe3\n\x1b\x64iscussion:discussion:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/discussions/{discussion_id}\x12\xbf\x01\n\x10\x44\x65leteDiscussion\x12(.eolymp.discussion.DeleteDiscussionInput\x1a).eolymp.discussion.DeleteDiscussionOutput\"V\x82\xe3\n\x1f\x8a\xe3\n\x1b\x64iscussion:discussion:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/discussions/{discussion_id}\x12\xbe\x01\n\x0eVoteDiscussion\x12&.eolymp.discussion.VoteDiscussionInput\x1a\'.eolymp.discussion.VoteDiscussionOutput\"[\x82\xe3\n\x1f\x8a\xe3\n\x1b\x64iscussion:discussion:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02#\"!/discussions/{discussion_id}/voteB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.discussion_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _DISCUSSIONSERVICE.methods_by_name['DescribeDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['DescribeDiscussion']._serialized_options = b'\202\343\n\036\212\343\n\032discussion:discussion:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\036\022\034/discussions/{discussion_id}'
  _DISCUSSIONSERVICE.methods_by_name['ListDiscussions']._options = None
  _DISCUSSIONSERVICE.methods_by_name['ListDiscussions']._serialized_options = b'\202\343\n\036\212\343\n\032discussion:discussion:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/discussions'
  _DISCUSSIONSERVICE.methods_by_name['CreateDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['CreateDiscussion']._serialized_options = b'\202\343\n\037\212\343\n\033discussion:discussion:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\"\014/discussions'
  _DISCUSSIONSERVICE.methods_by_name['UpdateDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['UpdateDiscussion']._serialized_options = b'\202\343\n\037\212\343\n\033discussion:discussion:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/discussions/{discussion_id}'
  _DISCUSSIONSERVICE.methods_by_name['DeleteDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['DeleteDiscussion']._serialized_options = b'\202\343\n\037\212\343\n\033discussion:discussion:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/discussions/{discussion_id}'
  _DISCUSSIONSERVICE.methods_by_name['VoteDiscussion']._options = None
  _DISCUSSIONSERVICE.methods_by_name['VoteDiscussion']._serialized_options = b'\202\343\n\037\212\343\n\033discussion:discussion:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002#\"!/discussions/{discussion_id}/vote'
  _DESCRIBEDISCUSSIONINPUT._serialized_start=235
  _DESCRIBEDISCUSSIONINPUT._serialized_end=299
  _DESCRIBEDISCUSSIONOUTPUT._serialized_start=301
  _DESCRIBEDISCUSSIONOUTPUT._serialized_end=378
  _LISTDISCUSSIONSINPUT._serialized_start=381
  _LISTDISCUSSIONSINPUT._serialized_end=583
  _LISTDISCUSSIONSINPUT_FILTER._serialized_start=516
  _LISTDISCUSSIONSINPUT_FILTER._serialized_end=583
  _LISTDISCUSSIONSOUTPUT._serialized_start=585
  _LISTDISCUSSIONSOUTPUT._serialized_end=669
  _CREATEDISCUSSIONINPUT._serialized_start=671
  _CREATEDISCUSSIONINPUT._serialized_end=745
  _CREATEDISCUSSIONOUTPUT._serialized_start=747
  _CREATEDISCUSSIONOUTPUT._serialized_end=794
  _UPDATEDISCUSSIONINPUT._serialized_start=796
  _UPDATEDISCUSSIONINPUT._serialized_end=893
  _UPDATEDISCUSSIONOUTPUT._serialized_start=895
  _UPDATEDISCUSSIONOUTPUT._serialized_end=919
  _DELETEDISCUSSIONINPUT._serialized_start=921
  _DELETEDISCUSSIONINPUT._serialized_end=967
  _DELETEDISCUSSIONOUTPUT._serialized_start=969
  _DELETEDISCUSSIONOUTPUT._serialized_end=993
  _VOTEDISCUSSIONINPUT._serialized_start=995
  _VOTEDISCUSSIONINPUT._serialized_end=1053
  _VOTEDISCUSSIONOUTPUT._serialized_start=1055
  _VOTEDISCUSSIONOUTPUT._serialized_end=1097
  _DISCUSSIONSERVICE._serialized_start=1100
  _DISCUSSIONSERVICE._serialized_end=2252
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ConfigurePolygonInput(_message.Message):
    __slots__ = ["password", "username"]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    password: str
    username: str
    def __init__(self, username: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class ConfigurePolygonOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribePolygonInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribePolygonOutput(_message.Message):
    __slots__ = ["password_set", "username"]
    PASSWORD_SET_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    password_set: bool
    username: str
    def __init__(self, username: _Optional[str] = ..., password_set: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/customer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import address_pb2 as eolymp_dot_commerce_dot_address__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/commerce/customer.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/commerce/address.proto\"\xbd\x02\n\x08\x43ustomer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\n \x01(\t\x12\r\n\x05phone\x18\x0b \x01(\t\x12\x13\n\x0btax_id_type\x18\x14 \x01(\t\x12\x14\n\x0ctax_id_value\x18\x15 \x01(\t\x12)\n\x07\x61\x64\x64ress\x18\x1e \x01(\x0b\x32\x18.eolymp.commerce.Address\x12\x10\n\x08\x63urrency\x18Z \x01(\t\x12\x10\n\x08language\x18[ \x01(\t\x12\x39\n\x08metadata\x18\x64 \x03(\x0b\x32\'.eolymp.commerce.Customer.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.customer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _CUSTOMER_METADATAENTRY._options = None
  _CUSTOMER_METADATAENTRY._serialized_options = b'8\001'
  _CUSTOMER._serialized_start=83
  _CUSTOMER._serialized_end=400
  _CUSTOMER_METADATAENTRY._serialized_start=353
  _CUSTOMER_METADATAENTRY._serialized_end=400
# @@protoc_insertion_point(module_scope)



from eolymp.atlas import testing_feedback_pb2 as _testing_feedback_pb2
from eolymp.atlas import testing_scoring_pb2 as _testing_scoring_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Submission(_message.Message):
    __slots__ = ["cost", "cpu_time_usage", "error", "groups", "id", "lang", "member_id", "memory_usage", "percentage", "problem_id", "resource_usage", "score", "signature", "source", "status", "submitted_at", "user_id", "verdict", "wall_time_usage"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Verdict(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Group(_message.Message):
        __slots__ = ["cost", "cpu_time_usage", "dependencies", "feedback_policy", "index", "memory_usage", "resource_usage", "runs", "score", "scoring_mode", "status", "testset_id", "verdict", "wall_time_usage"]
        class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ACCEPTED: Submission.Group.Status
        BLOCKED: Submission.Group.Status
        COST_FIELD_NUMBER: _ClassVar[int]
        CPU_EXHAUSTED: Submission.Group.Status
        CPU_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        DEPENDENCIES_FIELD_NUMBER: _ClassVar[int]
        FEEDBACK_POLICY_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        INTERACTION_ERROR: Submission.Group.Status
        MEMORY_OVERFLOW: Submission.Group.Status
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        PENDING: Submission.Group.Status
        RESOURCE_USAGE_FIELD_NUMBER: _ClassVar[int]
        RUNS_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_ERROR: Submission.Group.Status
        SCORE_FIELD_NUMBER: _ClassVar[int]
        SCORING_MODE_FIELD_NUMBER: _ClassVar[int]
        SKIPPED: Submission.Group.Status
        STATUS_FIELD_NUMBER: _ClassVar[int]
        TESTING: Submission.Group.Status
        TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
        TIMEOUT: Submission.Group.Status
        UNKNOWN: Submission.Group.Status
        VERDICT_FIELD_NUMBER: _ClassVar[int]
        VERIFICATION_ERROR: Submission.Group.Status
        WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        WRONG_ANSWER: Submission.Group.Status
        cost: float
        cpu_time_usage: int
        dependencies: _containers.RepeatedScalarFieldContainer[int]
        feedback_policy: _testing_feedback_pb2.FeedbackPolicy
        index: int
        memory_usage: int
        resource_usage: float
        runs: _containers.RepeatedCompositeFieldContainer[Submission.Run]
        score: float
        scoring_mode: _testing_scoring_pb2.ScoringMode
        status: Submission.Group.Status
        testset_id: str
        verdict: Submission.Verdict
        wall_time_usage: int
        def __init__(self, index: _Optional[int] = ..., testset_id: _Optional[str] = ..., status: _Optional[_Union[Submission.Group.Status, str]] = ..., verdict: _Optional[_Union[Submission.Verdict, str]] = ..., dependencies: _Optional[_Iterable[int]] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ..., scoring_mode: _Optional[_Union[_testing_scoring_pb2.ScoringMode, str]] = ..., feedback_policy: _Optional[_Union[_testing_feedback_pb2.FeedbackPolicy, str]] = ..., wall_time_usage: _Optional[int] = ..., cpu_time_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., resource_usage: _Optional[float] = ..., runs: _Optional[_Iterable[_Union[Submission.Run, _Mapping]]] = ...) -> None: ...
    class InteractorExecutionData(_message.Message):
        __slots__ = ["exit_code", "log_url", "memory_usage", "wall_time_usage"]
        EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
        LOG_URL_FIELD_NUMBER: _ClassVar[int]
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        exit_code: int
        log_url: str
        memory_usage: int
        wall_time_usage: int
        def __init__(self, log_url: _Optional[str] = ..., wall_time_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., exit_code: _Optional[int] = ...) -> None: ...
    class Run(_message.Message):
        __slots__ = ["cost", "cpu_time_usage", "id", "index", "interactor_execution_data", "memory_usage", "output_url", "resource_usage", "score", "status", "stderr_url", "test_id", "verdict", "verifier_execution_data", "wall_time_usage"]
        class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ACCEPTED: Submission.Run.Status
        BLOCKED: Submission.Run.Status
        COMPLETE: Submission.Run.Status
        COST_FIELD_NUMBER: _ClassVar[int]
        CPU_EXHAUSTED: Submission.Run.Status
        CPU_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        CREATED: Submission.Run.Status
        EXECUTING: Submission.Run.Status
        ID_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        INTERACTION_ERROR: Submission.Run.Status
        INTERACTOR_EXECUTION_DATA_FIELD_NUMBER: _ClassVar[int]
        MEMORY_OVERFLOW: Submission.Run.Status
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        NO_STATUS: Submission.Run.Status
        OUTPUT_URL_FIELD_NUMBER: _ClassVar[int]
        RESOURCE_USAGE_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_ERROR: Submission.Run.Status
        SCORE_FIELD_NUMBER: _ClassVar[int]
        SKIPPED: Submission.Run.Status
        STATUS_FIELD_NUMBER: _ClassVar[int]
        STDERR_URL_FIELD_NUMBER: _ClassVar[int]
        TEST_ID_FIELD_NUMBER: _ClassVar[int]
        TIMEOUT: Submission.Run.Status
        VERDICT_FIELD_NUMBER: _ClassVar[int]
        VERIFICATION_ERROR: Submission.Run.Status
        VERIFIER_EXECUTION_DATA_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        WRONG_ANSWER: Submission.Run.Status
        cost: float
        cpu_time_usage: int
        id: str
        index: int
        interactor_execution_data: Submission.InteractorExecutionData
        memory_usage: int
        output_url: str
        resource_usage: float
        score: float
        status: Submission.Run.Status
        stderr_url: str
        test_id: str
        verdict: Submission.Verdict
        verifier_execution_data: Submission.VerifierExecutionData
        wall_time_usage: int
        def __init__(self, id: _Optional[str] = ..., wall_time_usage: _Optional[int] = ..., cpu_time_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., resource_usage: _Optional[float] = ..., output_url: _Optional[str] = ..., stderr_url: _Optional[str] = ..., index: _Optional[int] = ..., test_id: _Optional[str] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ..., status: _Optional[_Union[Submission.Run.Status, str]] = ..., verdict: _Optional[_Union[Submission.Verdict, str]] = ..., verifier_execution_data: _Optional[_Union[Submission.VerifierExecutionData, _Mapping]] = ..., interactor_execution_data: _Optional[_Union[Submission.InteractorExecutionData, _Mapping]] = ...) -> None: ...
    class VerifierExecutionData(_message.Message):
        __slots__ = ["exit_code", "log_url", "memory_usage", "wall_time_usage"]
        EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
        LOG_URL_FIELD_NUMBER: _ClassVar[int]
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        exit_code: int
        log_url: str
        memory_usage: int
        wall_time_usage: int
        def __init__(self, log_url: _Optional[str] = ..., wall_time_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., exit_code: _Optional[int] = ...) -> None: ...
    ACCEPTED: Submission.Verdict
    COMPLETE: Submission.Status
    COST_FIELD_NUMBER: _ClassVar[int]
    CPU_EXHAUSTED: Submission.Verdict
    CPU_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
    ERROR: Submission.Status
    ERROR_FIELD_NUMBER: _ClassVar[int]
    FAILURE: Submission.Status
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LANG_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    MEMORY_OVERFLOW: Submission.Verdict
    MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
    NONE: Submission.Status
    NO_VERDICT: Submission.Verdict
    PENDING: Submission.Status
    PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_USAGE_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_ERROR: Submission.Verdict
    SCORE_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBMITTED_AT_FIELD_NUMBER: _ClassVar[int]
    TESTING: Submission.Status
    TIMEOUT: Submission.Status
    TIME_LIMIT_EXCEEDED: Submission.Verdict
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
    WRONG_ANSWER: Submission.Verdict
    cost: float
    cpu_time_usage: int
    error: str
    groups: _containers.RepeatedCompositeFieldContainer[Submission.Group]
    id: str
    lang: str
    member_id: str
    memory_usage: int
    percentage: float
    problem_id: str
    resource_usage: float
    score: float
    signature: str
    source: str
    status: Submission.Status
    submitted_at: _timestamp_pb2.Timestamp
    user_id: str
    verdict: Submission.Verdict
    wall_time_usage: int
    def __init__(self, id: _Optional[str] = ..., problem_id: _Optional[str] = ..., user_id: _Optional[str] = ..., member_id: _Optional[str] = ..., submitted_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., lang: _Optional[str] = ..., source: _Optional[str] = ..., signature: _Optional[str] = ..., status: _Optional[_Union[Submission.Status, str]] = ..., verdict: _Optional[_Union[Submission.Verdict, str]] = ..., error: _Optional[str] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ..., percentage: _Optional[float] = ..., wall_time_usage: _Optional[int] = ..., cpu_time_usage: _Optional[int] = ..., memory_usage: _Optional[int] = ..., resource_usage: _Optional[float] = ..., groups: _Optional[_Iterable[_Union[Submission.Group, _Mapping]]] = ...) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Discussion(_message.Message):
    __slots__ = ["created_at", "id", "links", "member_id", "message", "reply_count", "subject", "updated_at", "url", "vote_count"]
    class LinksEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    REPLY_COUNT_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    created_at: _timestamp_pb2.Timestamp
    id: str
    links: _containers.ScalarMap[str, str]
    member_id: str
    message: _content_pb2.Content
    reply_count: int
    subject: str
    updated_at: _timestamp_pb2.Timestamp
    url: str
    vote_count: int
    def __init__(self, id: _Optional[str] = ..., member_id: _Optional[str] = ..., url: _Optional[str] = ..., links: _Optional[_Mapping[str, str]] = ..., vote_count: _Optional[int] = ..., reply_count: _Optional[int] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., subject: _Optional[str] = ..., message: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.commerce import invoice_pb2 as _invoice_pb2
from eolymp.universe import billing_pb2 as _billing_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CancelSubscriptionInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CancelSubscriptionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreatePortalLinkInput(_message.Message):
    __slots__ = ["back_url", "complete_url", "flow", "return_url"]
    BACK_URL_FIELD_NUMBER: _ClassVar[int]
    COMPLETE_URL_FIELD_NUMBER: _ClassVar[int]
    FLOW_FIELD_NUMBER: _ClassVar[int]
    RETURN_URL_FIELD_NUMBER: _ClassVar[int]
    back_url: str
    complete_url: str
    flow: str
    return_url: str
    def __init__(self, flow: _Optional[str] = ..., back_url: _Optional[str] = ..., return_url: _Optional[str] = ..., complete_url: _Optional[str] = ...) -> None: ...

class CreatePortalLinkOutput(_message.Message):
    __slots__ = ["portal_link"]
    PORTAL_LINK_FIELD_NUMBER: _ClassVar[int]
    portal_link: str
    def __init__(self, portal_link: _Optional[str] = ...) -> None: ...

class CreateSubscriptionInput(_message.Message):
    __slots__ = ["plan_id", "seats", "variant_id"]
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    SEATS_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    plan_id: str
    seats: int
    variant_id: str
    def __init__(self, plan_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., seats: _Optional[int] = ...) -> None: ...

class CreateSubscriptionOutput(_message.Message):
    __slots__ = ["checkout_url"]
    CHECKOUT_URL_FIELD_NUMBER: _ClassVar[int]
    checkout_url: str
    def __init__(self, checkout_url: _Optional[str] = ...) -> None: ...

class DescribeBillingInformationInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeBillingInformationOutput(_message.Message):
    __slots__ = ["info"]
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _billing_pb2.Billing.Information
    def __init__(self, info: _Optional[_Union[_billing_pb2.Billing.Information, _Mapping]] = ...) -> None: ...

class DescribeInvoiceInput(_message.Message):
    __slots__ = ["invoice_id"]
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    def __init__(self, invoice_id: _Optional[str] = ...) -> None: ...

class DescribeInvoiceOutput(_message.Message):
    __slots__ = ["invoice"]
    INVOICE_FIELD_NUMBER: _ClassVar[int]
    invoice: _invoice_pb2.Invoice
    def __init__(self, invoice: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ...) -> None: ...

class DescribeSubscriptionInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeSubscriptionOutput(_message.Message):
    __slots__ = ["current", "upcoming"]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    UPCOMING_FIELD_NUMBER: _ClassVar[int]
    current: _billing_pb2.Billing.Subscription
    upcoming: _billing_pb2.Billing.Subscription
    def __init__(self, current: _Optional[_Union[_billing_pb2.Billing.Subscription, _Mapping]] = ..., upcoming: _Optional[_Union[_billing_pb2.Billing.Subscription, _Mapping]] = ...) -> None: ...

class ListInvoicesInput(_message.Message):
    __slots__ = ["after", "before", "size"]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    after: str
    before: str
    size: int
    def __init__(self, size: _Optional[int] = ..., after: _Optional[str] = ..., before: _Optional[str] = ...) -> None: ...

class ListInvoicesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_invoice_pb2.Invoice]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_invoice_pb2.Invoice, _Mapping]]] = ...) -> None: ...

class PayInvoiceInput(_message.Message):
    __slots__ = ["invoice_id"]
    INVOICE_ID_FIELD_NUMBER: _ClassVar[int]
    invoice_id: str
    def __init__(self, invoice_id: _Optional[str] = ...) -> None: ...

class PayInvoiceOutput(_message.Message):
    __slots__ = ["checkout_url"]
    CHECKOUT_URL_FIELD_NUMBER: _ClassVar[int]
    checkout_url: str
    def __init__(self, checkout_url: _Optional[str] = ...) -> None: ...

class SimulateSubscriptionInput(_message.Message):
    __slots__ = ["coupon", "plan_id", "seats", "variant_id"]
    COUPON_FIELD_NUMBER: _ClassVar[int]
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    SEATS_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    coupon: str
    plan_id: str
    seats: int
    variant_id: str
    def __init__(self, plan_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., seats: _Optional[int] = ..., coupon: _Optional[str] = ...) -> None: ...

class SimulateSubscriptionOutput(_message.Message):
    __slots__ = ["due", "invoice"]
    DUE_FIELD_NUMBER: _ClassVar[int]
    INVOICE_FIELD_NUMBER: _ClassVar[int]
    due: _invoice_pb2.Invoice
    invoice: _invoice_pb2.Invoice
    def __init__(self, due: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ..., invoice: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ...) -> None: ...

class UpcomingInvoiceInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpcomingInvoiceOutput(_message.Message):
    __slots__ = ["invoice"]
    INVOICE_FIELD_NUMBER: _ClassVar[int]
    invoice: _invoice_pb2.Invoice
    def __init__(self, invoice: _Optional[_Union[_invoice_pb2.Invoice, _Mapping]] = ...) -> None: ...

class UpdateBillingInformationInput(_message.Message):
    __slots__ = ["info"]
    INFO_FIELD_NUMBER: _ClassVar[int]
    info: _billing_pb2.Billing.Information
    def __init__(self, info: _Optional[_Union[_billing_pb2.Billing.Information, _Mapping]] = ...) -> None: ...

class UpdateBillingInformationOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateSubscriptionInput(_message.Message):
    __slots__ = ["plan_id", "seats", "variant_id"]
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    SEATS_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    plan_id: str
    seats: int
    variant_id: str
    def __init__(self, plan_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., seats: _Optional[int] = ...) -> None: ...

class UpdateSubscriptionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Version(_message.Message):
    __slots__ = ["change_op", "change_path", "created_at", "created_by", "number"]
    CHANGE_OP_FIELD_NUMBER: _ClassVar[int]
    CHANGE_PATH_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    change_op: str
    change_path: str
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    number: int
    def __init__(self, number: _Optional[int] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., change_op: _Optional[str] = ..., change_path: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Plan(_message.Message):
    __slots__ = ["id", "name", "variants"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Recurrence(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Variant(_message.Message):
        __slots__ = ["currency", "id", "recurrence", "unit_amount"]
        CURRENCY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        RECURRENCE_FIELD_NUMBER: _ClassVar[int]
        UNIT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        currency: str
        id: str
        recurrence: Plan.Recurrence
        unit_amount: int
        def __init__(self, id: _Optional[str] = ..., recurrence: _Optional[_Union[Plan.Recurrence, str]] = ..., currency: _Optional[str] = ..., unit_amount: _Optional[int] = ...) -> None: ...
    DESCRIPTION_RENDER: Plan.Extra
    DESCRIPTION_VALUE: Plan.Extra
    ID_FIELD_NUMBER: _ClassVar[int]
    MONTHLY: Plan.Recurrence
    NAME_FIELD_NUMBER: _ClassVar[int]
    NO_EXTRA: Plan.Extra
    ONETIME: Plan.Recurrence
    UNKNOWN_RECURRENCE: Plan.Recurrence
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    YEARLY: Plan.Recurrence
    id: str
    name: str
    variants: _containers.RepeatedCompositeFieldContainer[Plan.Variant]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., variants: _Optional[_Iterable[_Union[Plan.Variant, _Mapping]]] = ...) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Forum(_message.Message):
    __slots__ = ["id", "links", "parent_id", "summary", "title", "url"]
    class LinksEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    id: str
    links: _containers.ScalarMap[str, str]
    parent_id: str
    summary: _content_pb2.Content
    title: str
    url: str
    def __init__(self, id: _Optional[str] = ..., parent_id: _Optional[str] = ..., url: _Optional[str] = ..., links: _Optional[_Mapping[str, str]] = ..., title: _Optional[str] = ..., summary: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/commerce/product_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.commerce import price_pb2 as eolymp_dot_commerce_dot_price__pb2
from eolymp.commerce import product_pb2 as eolymp_dot_commerce_dot_product__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/commerce/product_service.proto\x12\x0f\x65olymp.commerce\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1b\x65olymp/commerce/price.proto\x1a\x1d\x65olymp/commerce/product.proto\"?\n\x12\x43reateProductInput\x12)\n\x07product\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Product\")\n\x13\x43reateProductOutput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"S\n\x12UpdateProductInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12)\n\x07product\x18\x02 \x01(\x0b\x32\x18.eolymp.commerce.Product\"\x15\n\x13UpdateProductOutput\"\x85\x01\n\x11ListProductsInput\x12@\n\x07\x66ilters\x18\x01 \x03(\x0b\x32/.eolymp.commerce.ListProductsInput.FiltersEntry\x1a.\n\x0c\x46iltersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\x12ListProductsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.commerce.Product\"*\n\x14\x44\x65scribeProductInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"B\n\x15\x44\x65scribeProductOutput\x12)\n\x07product\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Product\"(\n\x12\x44\x65leteProductInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProductOutput\">\n\x16ListProductPricesInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\"@\n\x17ListProductPricesOutput\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.commerce.Price\"A\n\x19\x44\x65scribeProductPriceInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x10\n\x08price_id\x18\x02 \x01(\t\"C\n\x1a\x44\x65scribeProductPriceOutput\x12%\n\x05price\x18\x01 \x01(\x0b\x32\x16.eolymp.commerce.Price\"T\n\x17\x43reateProductPriceInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12%\n\x05price\x18\x02 \x01(\x0b\x32\x16.eolymp.commerce.Price\",\n\x18\x43reateProductPriceOutput\x12\x10\n\x08price_id\x18\x01 \x01(\t\"?\n\x17\x44\x65leteProductPriceInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x10\n\x08price_id\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteProductPriceOutput2\xa8\x08\n\x0eProductService\x12k\n\rCreateProduct\x12#.eolymp.commerce.CreateProductInput\x1a$.eolymp.commerce.CreateProductOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12k\n\rUpdateProduct\x12#.eolymp.commerce.UpdateProductInput\x1a$.eolymp.commerce.UpdateProductOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12q\n\x0f\x44\x65scribeProduct\x12%.eolymp.commerce.DescribeProductInput\x1a&.eolymp.commerce.DescribeProductOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12h\n\x0cListProducts\x12\".eolymp.commerce.ListProductsInput\x1a#.eolymp.commerce.ListProductsOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12k\n\rDeleteProduct\x12#.eolymp.commerce.DeleteProductInput\x1a$.eolymp.commerce.DeleteProductOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12w\n\x11ListProductPrices\x12\'.eolymp.commerce.ListProductPricesInput\x1a(.eolymp.commerce.ListProductPricesOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12\x80\x01\n\x14\x44\x65scribeProductPrice\x12*.eolymp.commerce.DescribeProductPriceInput\x1a+.eolymp.commerce.DescribeProductPriceOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12z\n\x12\x43reateProductPrice\x12(.eolymp.commerce.CreateProductPriceInput\x1a).eolymp.commerce.CreateProductPriceOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x12z\n\x12\x44\x65leteProductPrice\x12(.eolymp.commerce.DeleteProductPriceInput\x1a).eolymp.commerce.DeleteProductPriceOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2B3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.product_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _LISTPRODUCTSINPUT_FILTERSENTRY._options = None
  _LISTPRODUCTSINPUT_FILTERSENTRY._serialized_options = b'8\001'
  _PRODUCTSERVICE.methods_by_name['CreateProduct']._options = None
  _PRODUCTSERVICE.methods_by_name['CreateProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _PRODUCTSERVICE.methods_by_name['UpdateProduct']._options = None
  _PRODUCTSERVICE.methods_by_name['UpdateProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _PRODUCTSERVICE.methods_by_name['DescribeProduct']._options = None
  _PRODUCTSERVICE.methods_by_name['DescribeProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _PRODUCTSERVICE.methods_by_name['ListProducts']._options = None
  _PRODUCTSERVICE.methods_by_name['ListProducts']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _PRODUCTSERVICE.methods_by_name['DeleteProduct']._options = None
  _PRODUCTSERVICE.methods_by_name['DeleteProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _PRODUCTSERVICE.methods_by_name['ListProductPrices']._options = None
  _PRODUCTSERVICE.methods_by_name['ListProductPrices']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _PRODUCTSERVICE.methods_by_name['DescribeProductPrice']._options = None
  _PRODUCTSERVICE.methods_by_name['DescribeProductPrice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _PRODUCTSERVICE.methods_by_name['CreateProductPrice']._options = None
  _PRODUCTSERVICE.methods_by_name['CreateProductPrice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _PRODUCTSERVICE.methods_by_name['DeleteProductPrice']._options = None
  _PRODUCTSERVICE.methods_by_name['DeleteProductPrice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2'
  _CREATEPRODUCTINPUT._serialized_start=154
  _CREATEPRODUCTINPUT._serialized_end=217
  _CREATEPRODUCTOUTPUT._serialized_start=219
  _CREATEPRODUCTOUTPUT._serialized_end=260
  _UPDATEPRODUCTINPUT._serialized_start=262
  _UPDATEPRODUCTINPUT._serialized_end=345
  _UPDATEPRODUCTOUTPUT._serialized_start=347
  _UPDATEPRODUCTOUTPUT._serialized_end=368
  _LISTPRODUCTSINPUT._serialized_start=371
  _LISTPRODUCTSINPUT._serialized_end=504
  _LISTPRODUCTSINPUT_FILTERSENTRY._serialized_start=458
  _LISTPRODUCTSINPUT_FILTERSENTRY._serialized_end=504
  _LISTPRODUCTSOUTPUT._serialized_start=506
  _LISTPRODUCTSOUTPUT._serialized_end=582
  _DESCRIBEPRODUCTINPUT._serialized_start=584
  _DESCRIBEPRODUCTINPUT._serialized_end=626
  _DESCRIBEPRODUCTOUTPUT._serialized_start=628
  _DESCRIBEPRODUCTOUTPUT._serialized_end=694
  _DELETEPRODUCTINPUT._serialized_start=696
  _DELETEPRODUCTINPUT._serialized_end=736
  _DELETEPRODUCTOUTPUT._serialized_start=738
  _DELETEPRODUCTOUTPUT._serialized_end=759
  _LISTPRODUCTPRICESINPUT._serialized_start=761
  _LISTPRODUCTPRICESINPUT._serialized_end=823
  _LISTPRODUCTPRICESOUTPUT._serialized_start=825
  _LISTPRODUCTPRICESOUTPUT._serialized_end=889
  _DESCRIBEPRODUCTPRICEINPUT._serialized_start=891
  _DESCRIBEPRODUCTPRICEINPUT._serialized_end=956
  _DESCRIBEPRODUCTPRICEOUTPUT._serialized_start=958
  _DESCRIBEPRODUCTPRICEOUTPUT._serialized_end=1025
  _CREATEPRODUCTPRICEINPUT._serialized_start=1027
  _CREATEPRODUCTPRICEINPUT._serialized_end=1111
  _CREATEPRODUCTPRICEOUTPUT._serialized_start=1113
  _CREATEPRODUCTPRICEOUTPUT._serialized_end=1157
  _DELETEPRODUCTPRICEINPUT._serialized_start=1159
  _DELETEPRODUCTPRICEINPUT._serialized_end=1222
  _DELETEPRODUCTPRICEOUTPUT._serialized_start=1224
  _DELETEPRODUCTPRICEOUTPUT._serialized_end=1250
  _PRODUCTSERVICE._serialized_start=1253
  _PRODUCTSERVICE._serialized_end=2317
# @@protoc_insertion_point(module_scope)



from eolymp.commerce import price_pb2 as _price_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Product(_message.Message):
    __slots__ = ["active", "default_price", "description", "id", "image", "name", "page_url", "unit_label"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_PRICE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PAGE_URL_FIELD_NUMBER: _ClassVar[int]
    UNIT_LABEL_FIELD_NUMBER: _ClassVar[int]
    active: bool
    default_price: _price_pb2.Price
    description: str
    id: str
    image: str
    name: str
    page_url: str
    unit_label: str
    def __init__(self, id: _Optional[str] = ..., active: bool = ..., name: _Optional[str] = ..., image: _Optional[str] = ..., description: _Optional[str] = ..., page_url: _Optional[str] = ..., unit_label: _Optional[str] = ..., default_price: _Optional[_Union[_price_pb2.Price, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/subscription.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/discussion/subscription.proto\x12\x11\x65olymp.discussion\"}\n\x0cSubscription\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.eolymp.discussion.Subscription.Type\"9\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05MUTED\x10\x01\x12\x0e\n\nSUBSCRIBED\x10\x02\x12\x0c\n\x08WATCHING\x10\x03\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.subscription_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _SUBSCRIPTION._serialized_start=59
  _SUBSCRIPTION._serialized_end=184
  _SUBSCRIPTION_TYPE._serialized_start=127
  _SUBSCRIPTION_TYPE._serialized_end=184
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.judge import reply_pb2 as eolymp_dot_judge_dot_reply__pb2
from eolymp.judge import score_pb2 as eolymp_dot_judge_dot_score__pb2
from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/judge/events.proto\x12\x0c\x65olymp.judge\x1a\x1e\x65olymp/judge/participant.proto\x1a\x18\x65olymp/judge/reply.proto\x1a\x18\x65olymp/judge/score.proto\x1a\x1d\x65olymp/judge/submission.proto\x1a\x19\x65olymp/judge/ticket.proto\"H\n\x18SubmissionCompletedEvent\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\"<\n\x11RebuildScoreEvent\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x02 \x01(\t\"w\n\x11ScoreUpdatedEvent\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x12\n\nunofficial\x18\x04 \x01(\x08\x12\"\n\x05score\x18\x03 \x01(\x0b\x32\x13.eolymp.judge.Score\":\n\x12TicketCreatedEvent\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"^\n\x12TicketUpdatedEvent\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\x12\"\n\x05reply\x18\x02 \x01(\x0b\x32\x13.eolymp.judge.Reply\"I\n\x17ParticipantCreatedEvent\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"I\n\x17ParticipantUpdatedEvent\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"I\n\x17ParticipantDeletedEvent\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"Q\n\x12RetestProblemEvent\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x03 \x01(\t\"\xc0\x01\n\x12TicketChangeRecord\x12\x36\n\x02op\x18\x01 \x01(\x0e\x32*.eolymp.judge.TicketChangeRecord.Operation\x12$\n\x06ticket\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"L\n\tOperation\x12\x10\n\x0cNO_OPERATION\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\t\n\x05REPLY\x10\x05\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _SUBMISSIONCOMPLETEDEVENT._serialized_start=185
  _SUBMISSIONCOMPLETEDEVENT._serialized_end=257
  _REBUILDSCOREEVENT._serialized_start=259
  _REBUILDSCOREEVENT._serialized_end=319
  _SCOREUPDATEDEVENT._serialized_start=321
  _SCOREUPDATEDEVENT._serialized_end=440
  _TICKETCREATEDEVENT._serialized_start=442
  _TICKETCREATEDEVENT._serialized_end=500
  _TICKETUPDATEDEVENT._serialized_start=502
  _TICKETUPDATEDEVENT._serialized_end=596
  _PARTICIPANTCREATEDEVENT._serialized_start=598
  _PARTICIPANTCREATEDEVENT._serialized_end=671
  _PARTICIPANTUPDATEDEVENT._serialized_start=673
  _PARTICIPANTUPDATEDEVENT._serialized_end=746
  _PARTICIPANTDELETEDEVENT._serialized_start=748
  _PARTICIPANTDELETEDEVENT._serialized_end=821
  _RETESTPROBLEMEVENT._serialized_start=823
  _RETESTPROBLEMEVENT._serialized_end=904
  _TICKETCHANGERECORD._serialized_start=907
  _TICKETCHANGERECORD._serialized_end=1099
  _TICKETCHANGERECORD_OPERATION._serialized_start=1023
  _TICKETCHANGERECORD_OPERATION._serialized_end=1099
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.commerce import customer_pb2 as _customer_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateCustomerInput(_message.Message):
    __slots__ = ["customer"]
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: _customer_pb2.Customer
    def __init__(self, customer: _Optional[_Union[_customer_pb2.Customer, _Mapping]] = ...) -> None: ...

class CreateCustomerOutput(_message.Message):
    __slots__ = ["customer_id"]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    def __init__(self, customer_id: _Optional[str] = ...) -> None: ...

class DeleteCustomerInput(_message.Message):
    __slots__ = ["customer_id"]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    def __init__(self, customer_id: _Optional[str] = ...) -> None: ...

class DeleteCustomerOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeCustomerInput(_message.Message):
    __slots__ = ["customer_id"]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    def __init__(self, customer_id: _Optional[str] = ...) -> None: ...

class DescribeCustomerOutput(_message.Message):
    __slots__ = ["customer"]
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: _customer_pb2.Customer
    def __init__(self, customer: _Optional[_Union[_customer_pb2.Customer, _Mapping]] = ...) -> None: ...

class ListCustomersInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListCustomersOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_customer_pb2.Customer]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_customer_pb2.Customer, _Mapping]]] = ...) -> None: ...

class UpdateCustomerInput(_message.Message):
    __slots__ = ["customer", "customer_id"]
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    customer: _customer_pb2.Customer
    customer_id: str
    def __init__(self, customer_id: _Optional[str] = ..., customer: _Optional[_Union[_customer_pb2.Customer, _Mapping]] = ...) -> None: ...

class UpdateCustomerOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...
